@@ -1,5 +1,15 @@
 #!/usr/bin/env python
 # coding=utf-8
+
+__author__ = "Garrett Bates"
+__copyright__ = "© Copyright 2020-2021, Tartan Solutions, Inc"
+__credits__ = ["Garrett Bates"]
+__license__ = "Apache 2.0"
+__version__ = "0.1.4"
+__maintainer__ = "Garrett Bates"
+__email__ = "garrett.bates@tartansolutions.com"
+__status__ = "Development"
+
 """Loads the configuration file used by plaid apps in kubernetes."""
 import os
 import yaml
@@ -10,6 +20,10 @@ CONFIG_PATH = os.environ.get('PLAID_CONFIG_PATH', '/etc/plaidcloud/config.yaml')
 
 class DatabaseConfig(NamedTuple):
     hostname: str
+    port: int
+    superuser: str
+    password: str
+    system: str
 
 
 class EnvironmentConfig(NamedTuple):
@@ -35,9 +49,10 @@ class RMQConfig(NamedTuple):
     """Connection settings for a RabbitMQ instance."""
     username: str
     password: str
+    vhost: str
     event_username: str
     event_password: str
-    vhost: str
+    event_vhost: str
     hostname: str = "rabbit-rabbitmq-ha"
     port: int = 5679
 
